@@ -1324,6 +1324,8 @@ const char *connman_device_get_string(struct connman_device *device,
 		return device->name;
 	else if (g_str_equal(key, "Node") == TRUE)
 		return device->node;
+	else if (g_str_equal(key, "Interface") == TRUE)
+		return device->interface;
 
 	return connman_element_get_string(&device->element, key);
 }
@@ -1369,11 +1371,17 @@ int __connman_device_set_offlinemode(connman_bool_t offlinemode)
 
 void __connman_device_increase_connections(struct connman_device *device)
 {
+	if (device == NULL)
+		return;
+
 	device->connections++;
 }
 
 void __connman_device_decrease_connections(struct connman_device *device)
 {
+	if (device == NULL)
+		return;
+
 	device->connections--;
 }
 
